+++
title = "Publish date set using Org time stamp"
publishDate = 2018-01-23T00:00:00+00:00
tags = ["dates", "publishdate"]
draft = false
+++

The `publishdate` for this post is set in Org using the `C-c . RET`
binding.
